//
//  SlowupMapViewController.m
//  slowupDemo
//
//  Created by David Gerber on 21.10.11.
//  Copyright 2011 __MyCompanyName__. All rights reserved.
//

#import "SlowupMapViewController.h"
#import "MapDetailViewController.h"

#import "SlowupAnnotation.h"
#import "SlowupAnnotationView.h"


@implementation SlowupMapViewController
@synthesize map, kml, SchnottwilViewController, SolothurnViewController;
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)dealloc
{
    [super dealloc];
}

- (void)didReceiveMemoryWarning
{
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];

    // Locate the path to the route.kml file in the application's bundle
    // and parse it with the KMLParser.
    NSString *path = [[NSBundle mainBundle] pathForResource:@"solothurn" ofType:@"kml"];
    kml = [[KMLParser parseKMLAtPath:path] retain];
    
    // Add all of the MKOverlay objects parsed from the KML file to the map.
    NSArray *overlays = [kml overlays];
    [map addOverlays:overlays];
    
    // Add all of the MKAnnotation objects parsed from the KML file to the map.
    NSArray *annotations = [kml points];
    
    SlowupAnnotation *annotation = nil; 
    
    CLLocationDegrees latitude  = 47.103366;
    CLLocationDegrees longitude = 7.431537;
    
    CLLocation* currentLocation = [[[CLLocation alloc] initWithLatitude:latitude longitude:longitude] autorelease];
    
    annotation = [[[SlowupAnnotation alloc] initWithCoordinate:[currentLocation coordinate]
											   annotationType:SlowupMapAnnotationTypeWC
														title:@"WC"] autorelease];

    [map addAnnotation:annotation];

    
    latitude  = 47.145829;
    longitude = 7.45594;
    
    currentLocation = [[[CLLocation alloc] initWithLatitude:latitude longitude:longitude] autorelease];
    
    annotation = [[[SlowupAnnotation alloc] initWithCoordinate:[currentLocation coordinate]
                                                annotationType:SlowupMapAnnotationTypeMecano
                                                         title:@"Mecano"] autorelease];
    
    [map addAnnotation:annotation];
    
    
    latitude  = 47.154542;
    longitude = 7.523773;    
    currentLocation = [[[CLLocation alloc] initWithLatitude:latitude longitude:longitude] autorelease];
    annotation = [[[SlowupAnnotation alloc] initWithCoordinate:[currentLocation coordinate]
                                                annotationType:SlowupMapAnnotationTypeInfirmerie
                                                         title:@"WC"] autorelease];
    
    [map addAnnotation:annotation];

    latitude  = 47.181762;
    longitude = 7.557154;    
    currentLocation = [[[CLLocation alloc] initWithLatitude:latitude longitude:longitude] autorelease];
    annotation = [[[SlowupAnnotation alloc] initWithCoordinate:[currentLocation coordinate]
                                                annotationType:SlowupMapAnnotationTypeWCHandi
                                                         title:@"WC"] autorelease];
    
    [map addAnnotation:annotation];

    [map addAnnotations:annotations];

    
    // Walk the list of overlays and annotations and create a MKMapRect that
    // bounds all of them and store it into flyTo.
    MKMapRect flyTo = MKMapRectNull;
    for (id <MKOverlay> overlay in overlays) {
        if (MKMapRectIsNull(flyTo)) {
            flyTo = [overlay boundingMapRect];
        } else {
            flyTo = MKMapRectUnion(flyTo, [overlay boundingMapRect]);
        }
    }
    
    for (id <MKAnnotation> annotation in annotations) {
        MKMapPoint annotationPoint = MKMapPointForCoordinate(annotation.coordinate);
        MKMapRect pointRect = MKMapRectMake(annotationPoint.x, annotationPoint.y, 0, 0);
        if (MKMapRectIsNull(flyTo)) {
            flyTo = pointRect;
        } else {
            flyTo = MKMapRectUnion(flyTo, pointRect);
        }
    }
    
    // Position the map so that all overlays and annotations are visible on screen.
    map.visibleMapRect = flyTo;
    
    if (SchnottwilViewController == nil) {
        
        
        MapDetailViewController *theMapViewController =  [[MapDetailViewController alloc] initWithNibName:@"MapDetailViewController" bundle:nil];
        theMapViewController.title = @"Schnottwil";
        self.SchnottwilViewController = theMapViewController;
        self.SchnottwilViewController.url = @"http://www.smaps.ch/slowup/schnottwil.html"; 
        [theMapViewController release];
    }

    if (SolothurnViewController == nil) {
        
        
        MapDetailViewController *theMapViewController =  [[MapDetailViewController alloc] initWithNibName:@"MapDetailViewController" bundle:nil];
        theMapViewController.title = @"Solothurn";
        self.SolothurnViewController = theMapViewController;
        self.SolothurnViewController.url = @"http://www.smaps.ch/slowup/solothurn.html";
        [theMapViewController release];
    }   
    map.showsUserLocation = true;
    //map.delegate = self;
    
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}


#pragma mark MKMapViewDelegate
- (void)showDetails:(id)sender
{
    // the detail view does not want a toolbar so hide it
    UIButton *tempButton = sender;
    if (tempButton.tag == 1) {
    [self.navigationController pushViewController:self.SchnottwilViewController animated:YES];
    } else  {
    [self.navigationController pushViewController:self.SolothurnViewController animated:YES];
    }
    

}

- (MKOverlayView *)mapView:(MKMapView *)mapView viewForOverlay:(id <MKOverlay>)overlay
{
    return [kml viewForOverlay:overlay];
}

- (MKAnnotationView *)mapView:(MKMapView *)mapView viewForAnnotation:(id <MKAnnotation>)annotation
{
    if ([annotation isKindOfClass:[SlowupAnnotation class]]) {
        SlowupAnnotation *slowupAnnotation = (SlowupAnnotation*) annotation;
        SlowupAnnotationView *pin = [[[SlowupAnnotationView alloc] initWithAnnotation:slowupAnnotation reuseIdentifier:@"Images"] autorelease];

        return pin;
    } else {

//    self.detailViewController.url = [kml descriptionForAnnotation:annotation];

    MKPinAnnotationView *annotionView = [kml viewForAnnotation:annotation];

    UIButton* rightButton = [UIButton buttonWithType:UIButtonTypeDetailDisclosure];
    NSString *url = [kml descriptionForAnnotation:annotation];
        if ([url compare:@"http://www.smaps.ch/slowup/schnottwil.html"] == -0) {
            rightButton.tag = 1;
        }
    [rightButton addTarget:self
                    action:@selector(showDetails:)
          forControlEvents:UIControlEventTouchUpInside];
    annotionView.rightCalloutAccessoryView = rightButton;
    

    return annotionView;
    }
}
-(void) mapViewWillStartLoadingMap:(MKMapView *)mapView {
   	// Show the activity indicator in the status bar
	[UIApplication sharedApplication].networkActivityIndicatorVisible = YES; 
}

-(void) mapViewDidFinishLoadingMap:(MKMapView *)mapView {
	// Hide the activity indicator in the status bar
	[UIApplication sharedApplication].networkActivityIndicatorVisible = NO;    
}
-(void) mapViewDidFailLoadingMap:(MKMapView *)mapView withError:(NSError *)error {
	// Load error, hide the activity indicator in the status bar
	[UIApplication sharedApplication].networkActivityIndicatorVisible = NO;    
}

@end
